#' Types of Sampling Used for Articles in a Sample of Journals 
#'
#' @name journal
#' @docType data
#' @format Data frame with the following 3 variables: 
#' \describe{
#'   \item{numemp}{number of articles in 1988 that used sampling}
#'   \item{prob}{number of articlues that used probability sampling}
#'   \item{nonprob}{number of articles that used nonprobability sampling}
#' }   
#' @source Jacoby and Handlin (1991). TODO
#' @references Lohr (1999). Sampling: Design and Analysis, Duxbury, p. TODO and
#'   442. 
"journal"